@@ -287,8 +287,8 @@ impl GeneralReadout for NetBSDGeneralReadout {
         }
     }
 
-    fn shell(&self, shorthand: ShellFormat) -> Result<String, ReadoutError> {
-        crate::shared::shell(shorthand)
+    fn shell(&self, shorthand: ShellFormat, kind: ShellKind) -> Result<String, ReadoutError> {
+        crate::shared::shell(shorthand, kind)
     }
 
     fn cpu_model_name(&self) -> Result<String, ReadoutError> {
